@@ -23,7 +23,6 @@ import locale
 import logging
 import os
 import sys
-import time
 
 
 # Use basic stdout logging before we can initialize logging correctly.
@@ -48,10 +47,16 @@ except ValueError as err:
     sys.exit("Please install GTK (gir1.2-gtk-3.0).")
 
 try:
-    gi.require_version("GtkSource", "3.0")
-except ValueError as err:
-    logging.error(err)
-    sys.exit("Please install GtkSource (gir1.2-gtksource-3.0).")
+    gi.require_version("GtkSource", "4")
+    logging.info("Using GtkSourceView 4")
+except ValueError:
+    try:
+        gi.require_version("GtkSource", "3.0")
+        logging.info("Using GtkSourceView 3.0")
+    except ValueError:
+        sys.exit(
+            "Please install GtkSource (gir1.2-gtksource-3.0 or gir1.2-gtksource-4)."
+        )
 
 
 if hasattr(sys, "frozen"):
@@ -60,7 +65,7 @@ else:
     app_dir = os.path.dirname(os.path.abspath(__file__))
     base_dir = os.path.dirname(app_dir)
 
-print("Adding {} to sys.path".format(base_dir))
+print(f"Adding {base_dir} to sys.path")
 sys.path.insert(0, base_dir)
 
 from rednotebook.util import filesystem
@@ -71,6 +76,7 @@ from rednotebook.util import filesystem
 from rednotebook.external import elibintl
 
 LOCALE_PATH = filesystem.locale_dir
+logging.info(f"Locale path: {LOCALE_PATH}")
 
 GETTEXT_DOMAIN = "rednotebook"
 
@@ -84,7 +90,7 @@ translate
 
 1) works fine. For 3) we need a workaround in main_window.py. If we
 initialize libintl with elibintl, the translations for 2) stop working.
-Without the workaround we need to initalize libintl to avoid UTF-8
+Without the workaround we need to initialize libintl to avoid UTF-8
 encoding errors.
 
 When the problem is fixed upstream, we can pass libintl='libintl-8.dll'
@@ -161,16 +167,23 @@ setup_logging(dirs.log_file)
 logging.info("System encoding: %s" % filesystem.ENCODING)
 logging.info("Language code: %s" % filesystem.LANGUAGE)
 
+try:
+    import enchant
+
+    logging.info(f"Spell checking languages: {enchant.list_languages()}")
+    logging.info(f"Spell checking dictionaries: {enchant.list_dicts()}")
+except ImportError:
+    pass
+
 try:
     from gi.repository import Gtk
-    from gi.repository import GObject
+    from gi.repository import Gio
+    from gi.repository import GLib
 except (ImportError, AssertionError) as e:
     logging.error(e)
     logging.error("GTK not found. Please install it (gir1.2-gtk-3.0).")
     sys.exit(1)
 
-GObject.threads_init()
-
 
 from rednotebook.util import dates
 from rednotebook import backup
@@ -181,8 +194,20 @@ from rednotebook import storage
 from rednotebook.data import Month
 
 
-class Journal:
-    def __init__(self):
+class Journal(Gtk.Application):
+    def __init__(self, *args, **kwargs):
+        super().__init__(
+            *args,
+            application_id="app.rednotebook.RedNotebook",
+            flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
+            **kwargs,
+        )
+        # Let components check if the MainWindow has been created.
+        self.frame = None
+
+    def do_startup(self):
+        Gtk.Application.do_startup(self)
+
         self.dirs = dirs
 
         user_config = configuration.Config(self.dirs.config_file)
@@ -212,9 +237,7 @@ class Journal:
 
         self.actual_date = self.get_start_date()
 
-        # Let components check if the MainWindow has been created
-        self.frame = None
-        self.frame = MainWindow(self)
+        self.do_activate()
 
         journal_path = self.get_journal_path()
         if not self.dirs.is_valid_journal_path(journal_path):
@@ -232,14 +255,24 @@ class Journal:
         self.open_journal(journal_path)
 
         self.archiver = backup.Archiver(self)
-        GObject.idle_add(self.archiver.check_last_backup_date)
+        GLib.idle_add(self.archiver.check_last_backup_date)
 
         # Check for a new version
         if self.config.read("checkForNewVersion") == 1:
             utils.check_new_version(self, info.version, startup=True)
 
         # Automatically save the content after a period of time
-        GObject.timeout_add_seconds(600, self.save_to_disk)
+        GLib.timeout_add_seconds(600, self.save_to_disk)
+
+    def do_activate(self):
+        if not self.frame:
+            self.frame = MainWindow(self)
+        self.frame.main_frame.present()
+
+    def do_command_line(self, _command_line):
+        # Arguments are parsed elsewhere, so we only show the window here.
+        self.activate()
+        return 0  # Must return a number.
 
     def get_journal_path(self):
         """
@@ -306,7 +339,7 @@ class Journal:
             # Informs the logging system to perform an orderly shutdown by
             # flushing and closing all handlers.
             logging.shutdown()
-            Gtk.main_quit()
+            self.quit()
 
     def convert(self, text, target, headers=None, options=None, use_gtk_theme=False):
         options = options or {}
@@ -327,7 +360,7 @@ class Journal:
         try:
             filesystem.make_directory(self.dirs.data_dir)
         except OSError as err:
-            logging.error("Creating journal directory failed: {}".format(err))
+            logging.error(f"Creating journal directory failed: {err}")
             self.frame.show_save_error_dialog(exit_imminent)
             return True
 
@@ -336,7 +369,7 @@ class Journal:
                 self.months, self.dirs.data_dir, exit_imminent, saveas
             )
         except OSError as err:
-            logging.error("Saving month files failed: {}".format(err))
+            logging.error(f"Saving month files failed: {err}")
             self.frame.show_save_error_dialog(exit_imminent)
             something_saved = None
 
@@ -501,7 +534,7 @@ class Journal:
             log_level = logging.INFO
 
         self.frame.show_message(title, msg, msg_type)
-        logging.log(log_level, "{}. {}".format(title, msg) if title else msg)
+        logging.log(log_level, f"{title}. {msg}" if title else msg)
 
     @property
     def categories(self):
@@ -596,20 +629,12 @@ class Journal:
 
 
 def main():
-    start_time = time.time()
     journal = Journal()
     utils.setup_signal_handlers(journal)
-    end_time = time.time()
-    logging.debug("Start took %s seconds" % (end_time - start_time))
+    journal.run(sys.argv)
 
     try:
-        logging.debug("Trying to enter the gtk main loop")
-        Gtk.main()
-    except KeyboardInterrupt:
-        pass
-
-    try:
-        logging.info("Peak memory: {} KiB".format(filesystem.get_peak_memory_in_kb()))
+        logging.info(f"Peak memory: {filesystem.get_peak_memory_in_kb()} KiB")
     except Warning:
         pass
 
