@@ -1,8 +1,7 @@
 """
 This is PyInstaller hook file for CEF Python. This file
-helps pyinstaller find CEF Python dependencies that are
+helps PyInstaller find CEF Python dependencies that are
 required to run final executable.
-
 See PyInstaller docs for hooks:
 https://pyinstaller.readthedocs.io/en/stable/hooks.html
 """
@@ -13,9 +12,16 @@ import platform
 import re
 import sys
 import PyInstaller
-from PyInstaller.utils.hooks import is_module_satisfies
+from PyInstaller.utils.hooks import is_module_satisfies, get_package_paths
+from PyInstaller.compat import is_win, is_darwin, is_linux
 from PyInstaller import log as logging
 
+try:
+    # PyInstaller >= 4.0 doesn't support Python 2.7
+    from PyInstaller.compat import is_py2
+except ImportError:
+    is_py2 = None
+
 # Constants
 CEFPYTHON_MIN_VERSION = "57.0"
 PYINSTALLER_MIN_VERSION = "3.2.1"
@@ -24,14 +30,10 @@ PYINSTALLER_MIN_VERSION = "3.2.1"
 # TODO: use this code to work cross-platform:
 # > from PyInstaller.utils.hooks import get_package_paths
 # > get_package_paths("cefpython3")
-CEFPYTHON3_DIR = os.path.join(
-    os.path.dirname(sys.executable), "Lib", "site-packages", "cefpython3"
-)
 
-if platform.system() == "Windows":
-    CYTHON_MODULE_EXT = ".pyd"
-else:
-    CYTHON_MODULE_EXT = ".so"
+CEFPYTHON3_DIR = get_package_paths("cefpython3")[1]
+
+CYTHON_MODULE_EXT = ".pyd" if is_win else ".so"
 
 # Globals
 logger = logging.getLogger(__name__)
@@ -39,9 +41,10 @@ logger = logging.getLogger(__name__)
 
 # Functions
 def check_platforms():
-    if platform.system() != "Windows":
+    if not is_win and not is_darwin and not is_linux:
         raise SystemExit(
-            "Error: Currently only Windows platform is " " supported, see Issue #135."
+            "Error: Currently only Windows, Linux and Darwin "
+            "platforms are  supported, see Issue #135."
         )
 
 
@@ -52,7 +55,7 @@ def check_pyinstaller_version():
     # Example version string for dev version of pyinstaller:
     # > 3.3.dev0+g5dc9557c
     version = PyInstaller.__version__
-    match = re.search(r"^\d+\.\d+", version)
+    match = re.search(r"^\d+\.\d+(\.\d+)?", version)
     if not (match.group(0) >= PYINSTALLER_MIN_VERSION):
         raise SystemExit(
             "Error: pyinstaller %s or higher is required" % PYINSTALLER_MIN_VERSION
@@ -99,60 +102,104 @@ def get_excluded_cefpython_modules():
 
 
 def get_cefpython3_datas():
-    """Returning all cefpython binaries as DATAS, because
-    pyinstaller does strange things and fails if these are
+    """Returning almost all of cefpython binaries as DATAS (see exception
+    below), because pyinstaller does strange things and fails if these are
     returned as BINARIES. It first updates manifest in .dll files:
     >> Updating manifest in chrome_elf.dll
-
     And then because of that it fails to load the library:
     >> hsrc = win32api.LoadLibraryEx(filename, 0, LOAD_LIBRARY_AS_DATAFILE)
     >> pywintypes.error: (5, 'LoadLibraryEx', 'Access is denied.')
-
     It is not required for pyinstaller to modify in any way
     CEF binaries or to look for its dependencies. CEF binaries
     does not have any external dependencies like MSVCR or similar.
-
     The .pak .dat and .bin files cannot be marked as BINARIES
-    as pyinstaller would fail to find binary depdendencies on
+    as pyinstaller would fail to find binary dependencies on
     these files.
-
+    One exception is subprocess (subprocess.exe on Windows) executable
+    file, which is passed to pyinstaller as BINARIES in order to collect
+    its dependencies.
     DATAS are in format: tuple(full_path, dest_subdir).
     """
     ret = list()
 
+    if is_win:
+        cefdatadir = "."
+    elif is_darwin or is_linux:
+        cefdatadir = "."
+    else:
+        assert False, "Unsupported system {}".format(platform.system())
+
     # Binaries, licenses and readmes in the cefpython3/ directory
     for filename in os.listdir(CEFPYTHON3_DIR):
         # Ignore Cython modules which are already handled by
         # pyinstaller automatically.
-        if filename[:-4] in get_cefpython_modules():
+        if filename[: -len(CYTHON_MODULE_EXT)] in get_cefpython_modules():
             continue
-        # CEF binaries and datas
-        if (
-            filename[-4:]
-            in [
-                ".exe",
-                ".dll",
-                ".so",
-                ".pak",
-                ".dat",
-                ".bin",
-                ".txt",
-            ]
-            or filename in ["License", "subprocess"]
-        ):
-            logger.info("Include cefpython3 data: %s" % filename)
-            ret.append((os.path.join(CEFPYTHON3_DIR, filename), "."))
 
-    # The .pak files in cefpython3/locales/ directory
-    locales_dir = os.path.join(CEFPYTHON3_DIR, "locales")
-    assert os.path.exists(locales_dir), "locales/ dir not found in cefpython3"
-    for filename in os.listdir(locales_dir):
-        logger.info(
-            "Include cefpython3 data: {}/{}".format(
-                os.path.basename(locales_dir), filename
-            )
+        # CEF binaries and datas
+        extension = os.path.splitext(filename)[1]
+        if extension in [
+            ".exe",
+            ".dll",
+            ".pak",
+            ".dat",
+            ".bin",
+            ".txt",
+            ".so",
+            ".plist",
+        ] or filename.lower().startswith("license"):
+            logger.info("Include cefpython3 data: {}".format(filename))
+            ret.append((os.path.join(CEFPYTHON3_DIR, filename), cefdatadir))
+
+    if is_darwin:
+        # "Chromium Embedded Framework.framework/Resources" with subdirectories
+        # is required. Contain .pak files and locales (each locale in separate
+        # subdirectory).
+        resources_subdir = os.path.join(
+            "Chromium Embedded Framework.framework", "Resources"
         )
-        ret.append((os.path.join(locales_dir, filename), "locales"))
+        base_path = os.path.join(CEFPYTHON3_DIR, resources_subdir)
+        assert os.path.exists(base_path), "{} dir not found in cefpython3".format(
+            resources_subdir
+        )
+        for path, dirs, files in os.walk(base_path):
+            for file in files:
+                absolute_file_path = os.path.join(path, file)
+                dest_path = os.path.relpath(path, CEFPYTHON3_DIR)
+                ret.append((absolute_file_path, dest_path))
+                logger.info("Include cefpython3 data: {}".format(dest_path))
+    elif is_win or is_linux:
+        # The .pak files in cefpython3/locales/ directory
+        locales_dir = os.path.join(CEFPYTHON3_DIR, "locales")
+        assert os.path.exists(locales_dir), "locales/ dir not found in cefpython3"
+        for filename in os.listdir(locales_dir):
+            logger.info(
+                "Include cefpython3 data: {}/{}".format(
+                    os.path.basename(locales_dir), filename
+                )
+            )
+            ret.append(
+                (
+                    os.path.join(locales_dir, filename),
+                    os.path.join(cefdatadir, "locales"),
+                )
+            )
+
+        # Optional .so/.dll files in cefpython3/swiftshader/ directory
+        swiftshader_dir = os.path.join(CEFPYTHON3_DIR, "swiftshader")
+        if os.path.isdir(swiftshader_dir):
+            for filename in os.listdir(swiftshader_dir):
+                logger.info(
+                    "Include cefpython3 data: {}/{}".format(
+                        os.path.basename(swiftshader_dir), filename
+                    )
+                )
+                ret.append(
+                    (
+                        os.path.join(swiftshader_dir, filename),
+                        os.path.join(cefdatadir, "swiftshader"),
+                    )
+                )
     return ret
 
 
@@ -175,7 +222,6 @@ logger.info("CEF Python package directory: %s" % CEFPYTHON3_DIR)
 # TODO: Write a tool script that would find such imports in
 #       .pyx files automatically.
 hiddenimports = [
-    "base64",
     "codecs",
     "copy",
     "datetime",
@@ -192,14 +238,21 @@ hiddenimports = [
     "urllib",
     "weakref",
 ]
-if sys.version_info.major == 2:
-    hiddenimports += ["urlparse"]
+if is_py2:
+    hiddenimports += [
+        "urlparse",
+    ]
 
 # Excluded modules
 excludedimports = get_excluded_cefpython_modules()
 
-# Include binaries
-binaries = []
+# Include binaries requiring to collect its dependencies
+if is_darwin or is_linux:
+    binaries = [(os.path.join(CEFPYTHON3_DIR, "subprocess"), ".")]
+elif is_win:
+    binaries = [(os.path.join(CEFPYTHON3_DIR, "subprocess.exe"), ".")]
+else:
+    binaries = []
 
 # Include datas
 datas = get_cefpython3_datas()
